@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """APPROLE methods module."""
 import json
 from hvac import exceptions, utils
@@ -239,6 +238,7 @@ class AppRole(VaultApiBase):
         cidr_list=None,
         token_bound_cidrs=None,
         mount_point=DEFAULT_MOUNT_POINT,
+        wrap_ttl=None,
     ):
         """
         Generates and issues a new Secret ID on a role in the auth method.
@@ -256,6 +256,9 @@ class AppRole(VaultApiBase):
         :type token_bound_cidrs: list
         :param mount_point: The "path" the method/backend was mounted on.
         :type mount_point: str | unicode
+        :param wrap_ttl: Returns the request as a response-wrapping token.
+            Can be either an integer number of seconds or a string duration of seconds (`15s`), minutes (`20m`), or hours (`25h`).
+        :type wrap_ttl: int | str
         :return: The JSON response of the read_role_id request.
         :rtype: dict
         """
@@ -268,7 +271,9 @@ class AppRole(VaultApiBase):
                 )
             )
 
-        params = {"metadata": json.dumps(metadata) if metadata else metadata}
+        params = {}
+        if metadata:
+            params = {"metadata": json.dumps(metadata)}
 
         list_of_strings_params = {
             "cidr_list": cidr_list,
@@ -287,7 +292,7 @@ class AppRole(VaultApiBase):
             mount_point=mount_point,
             role_name=role_name,
         )
-        return self._adapter.post(url=api_path, json=params)
+        return self._adapter.post(url=api_path, json=params, wrap_ttl=wrap_ttl)
 
     def create_custom_secret_id(
         self,
@@ -297,6 +302,7 @@ class AppRole(VaultApiBase):
         cidr_list=None,
         token_bound_cidrs=None,
         mount_point=DEFAULT_MOUNT_POINT,
+        wrap_ttl=None,
     ):
         """
         Generates and issues a new Secret ID on a role in the auth method.
@@ -316,6 +322,9 @@ class AppRole(VaultApiBase):
         :type token_bound_cidrs: list
         :param mount_point: The "path" the method/backend was mounted on.
         :type mount_point: str | unicode
+        :param wrap_ttl: Returns the request as a response-wrapping token.
+            Can be either an integer number of seconds or a string duration of seconds (`15s`), minutes (`20m`), or hours (`25h`).
+        :type wrap_ttl: int | str
         :return: The JSON response of the read_role_id request.
         :rtype: dict
         """
@@ -328,7 +337,10 @@ class AppRole(VaultApiBase):
                 )
             )
 
-        params = {"secret_id": secret_id, "metadata": metadata}
+        params = {"secret_id": secret_id}
+
+        if metadata:
+            params["metadata"] = json.dumps(metadata)
 
         list_of_strings_params = {
             "cidr_list": cidr_list,
@@ -347,7 +359,7 @@ class AppRole(VaultApiBase):
             mount_point=mount_point,
             role_name=role_name,
         )
-        return self._adapter.post(url=api_path, json=params)
+        return self._adapter.post(url=api_path, json=params, wrap_ttl=wrap_ttl)
 
     def read_secret_id(self, role_name, secret_id, mount_point=DEFAULT_MOUNT_POINT):
         """
