@@ -5,11 +5,9 @@ from abc import ABCMeta
 logger = logging.getLogger(__name__)
 
 
-class VaultApiBase(object):
+class VaultApiBase(metaclass=ABCMeta):
     """Base class for API endpoints."""
 
-    __metaclass__ = ABCMeta
-
     def __init__(self, adapter):
         """Default api class constructor.
 
