@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 import logging
 from abc import ABCMeta
 
@@ -8,7 +7,5 @@ from hvac.api.vault_api_base import VaultApiBase
 logger = logging.getLogger(__name__)
 
 
-class SystemBackendMixin(VaultApiBase):
+class SystemBackendMixin(VaultApiBase, metaclass=ABCMeta):
     """Base class for System Backend API endpoints."""
-
-    __metaclass__ = ABCMeta
